@@ -4,7 +4,7 @@ require 5.008;
 use strict;
 use warnings;
 
-our $VERSION = '2.97';
+our $VERSION = '2.98';
 use Carp;
 use Symbol 'gensym', 'qualify_to_ref';    # For the 'any data type' hack
 use Fcntl qw( SEEK_SET SEEK_CUR );
@@ -2381,7 +2381,7 @@ Config::IniFiles - A module for reading .ini-style configuration files.
 
 =head1 VERSION
 
-version 2.97
+version 2.98
 
 =head1 SYNOPSIS
 
@@ -2396,6 +2396,10 @@ Config::IniFiles provides a way to have readable configuration files outside
 your Perl script. Configurations can be imported (inherited, stacked,...),
 sections can be grouped, and settings can be accessed from a tied hash.
 
+=head1 VERSION
+
+version 2.98
+
 =head1 FILE FORMAT
 
 INI files consist of a number of sections, each preceded with the
@@ -3338,8 +3342,7 @@ the same terms as the Perl 5 programming language system itself.
 =head1 BUGS
 
 Please report any bugs or feature requests on the bugtracker website
-L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=Config-IniFiles> or by email to
-L<bug-config-inifiles@rt.cpan.org|mailto:bug-config-inifiles@rt.cpan.org>.
+L<https://github.com/shlomif/Config-IniFiles/issues>
 
 When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
@@ -3448,8 +3451,8 @@ The code is open to the world, and available for you to hack on. Please feel fre
 with it, or whatever. If you want to contribute patches, please send me a diff or prod me to pull
 from your repository :)
 
-L<https://github.com/shlomif/perl-Config-IniFiles>
+L<https://github.com/shlomif/Config-IniFiles>
 
-  git clone ssh://git@github.com:shlomif/perl-Config-IniFiles.git
+  git clone git://github.com/shlomif/Config-IniFiles.git
 
 =cut
